
# Class: alt_description


an attributed description

URI: [linkml:AltDescription](https://w3id.org/linkml/AltDescription)


[![img](images/AltDescription.svg)](images/AltDescription.svg)

## Referenced by Class

 *  **[Element](Element.md)** *[alt_descriptions](alt_descriptions.md)*  <sub>0..\*</sub>  **[AltDescription](AltDescription.md)**

## Attributes


### Own

 * [alt_description➞source](alt_description_source.md)  <sub>1..1</sub>
     * Description: the source of an attributed description
     * Range: [String](types/String.md)
 * [alt_description➞description](alt_description_text.md)  <sub>1..1</sub>
     * Description: text of an attributed description
     * Range: [String](types/String.md)
